# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - ApproveChanges library

    @copyright: 2011 by Paul Boddie <paul@boddie.org.uk>
    @license: GNU GPL (v2 or later), see COPYING.txt for details.
"""

import re

__version__ = "0.1"

def get_queued_changes_page(request):
    return getattr(request.cfg, "queued_changes_page", "ApprovalQueue")

def get_approved_editors_group(request):
    return getattr(request.cfg, "approved_editors_group", "ApprovedGroup")

def is_queued_changes_page(request, pagename):

    "Return whether 'pagename' is a queued changes page by testing its name."

    parts = pagename.split("/")
    return len(parts) > 1 and parts[-1] == get_queued_changes_page(request)

def get_target_page_name(pagename):

    "Return the target page name for the given queued changes 'pagename'."

    return "/".join(pagename.split("/")[:-1])

# Utility classes and associated functions.
# NOTE: These are a subset of EventAggregatorSupport.

class Form:

    """
    A wrapper preserving MoinMoin 1.8.x (and earlier) behaviour in a 1.9.x
    environment.
    """

    def __init__(self, form):
        self.form = form

    def get(self, name, default=None):
        values = self.form.getlist(name)
        if not values:
            return default
        else:
            return values

    def __getitem__(self, name):
        return self.form.getlist(name)

class ActionSupport:

    """
    Work around disruptive MoinMoin changes in 1.9, and also provide useful
    convenience methods.
    """

    def get_form(self):
        return get_form(self.request)

def get_form(request):

    "Work around disruptive MoinMoin changes in 1.9."

    if hasattr(request, "values"):
        return Form(request.values)
    else:
        return request.form

# vim: tabstop=4 expandtab shiftwidth=4
